@@ -25,6 +25,7 @@ import qualified Network.Wai as W
 import Web.Cookie (parseCookiesText)
 import Data.ByteString (ByteString)
 import qualified Data.ByteString.Char8 as S8
+import qualified Data.ByteString.Lazy.Char8 as LS8
 import Data.Text (Text, pack)
 import Network.HTTP.Types (queryToQueryText, Status (Status))
 import Data.Maybe (fromMaybe, catMaybes)
@@ -33,18 +34,13 @@ import qualified Data.Set as Set
 import qualified Data.Text as T
 import Data.Text.Encoding (decodeUtf8With, decodeUtf8)
 import Data.Text.Encoding.Error (lenientDecode)
-import Data.Conduit
-import Data.Conduit.List (sourceList)
-import Data.Conduit.Binary (sourceFile, sinkFile)
+import Conduit
 import Data.Word (Word8, Word64)
-import Control.Monad.Trans.Resource (runResourceT, ResourceT)
 import Control.Exception (throwIO)
 import Control.Monad ((<=<), liftM)
 import Yesod.Core.Types
 import qualified Data.Map as Map
 import Data.IORef
-import qualified System.Random.MWC as MWC
-import Control.Monad.Primitive (PrimMonad, PrimState)
 import qualified Data.Vector.Storable as V
 import Data.ByteString.Internal (ByteString (PS))
 import qualified Data.Word8 as Word8
@@ -60,23 +56,29 @@ limitRequestBody maxLen req = do
             let len = fromIntegral $ S8.length bs
                 remaining' = remaining - len
             if remaining < len
-                then throwIO $ HCWai tooLargeResponse
+                then throwIO $ HCWai $ tooLargeResponse maxLen len
                 else do
                     writeIORef ref remaining'
                     return bs
         }
 
-tooLargeResponse :: W.Response
-tooLargeResponse = W.responseLBS
+tooLargeResponse :: Word64 -> Word64 -> W.Response
+tooLargeResponse maxLen bodyLen = W.responseLBS
     (Status 413 "Too Large")
     [("Content-Type", "text/plain")]
-    "Request body too large to be processed."
+    (L.concat 
+        [ "Request body too large to be processed. The maximum size is "
+        , (LS8.pack (show maxLen))
+        , " bytes; your request body was "
+        , (LS8.pack (show bodyLen))
+        , " bytes. If you're the developer of this site, you can configure the maximum length with the `maximumContentLength` function on the Yesod typeclass."
+        ])
 
 parseWaiRequest :: W.Request
                 -> SessionMap
                 -> Bool
                 -> Maybe Word64 -- ^ max body size
-                -> Either (IO YesodRequest) (MWC.GenIO -> IO YesodRequest)
+                -> Either (IO YesodRequest) (IO Int -> IO YesodRequest)
 parseWaiRequest env session useToken mmaxBodySize =
     -- In most cases, we won't need to generate any random values. Therefore,
     -- we split our results: if we need a random generator, return a Right
@@ -156,16 +158,21 @@ addTwoLetters (toAdd, exist) (l:ls) =
 -- | Generate a random String of alphanumerical characters
 -- (a-z, A-Z, and 0-9) of the given length using the given
 -- random number generator.
-randomString :: PrimMonad m => Int -> MWC.Gen (PrimState m) -> m Text
+randomString :: Monad m => Int -> m Int -> m Text
 randomString len gen =
     liftM (decodeUtf8 . fromByteVector) $ V.replicateM len asciiChar
   where
-    asciiChar = liftM toAscii $ MWC.uniformR (0, 61) gen
-
-    toAscii i
-        | i < 26 = i + Word8._A
-        | i < 52 = i + Word8._a - 26
-        | otherwise = i + Word8._0 - 52
+    asciiChar =
+      let loop = do
+            x <- gen
+            let y = fromIntegral $ x `mod` 64
+            case () of
+              ()
+                | y < 26 -> return $ y + Word8._A
+                | y < 52 -> return $ y + Word8._a - 26
+                | y < 62 -> return $ y + Word8._0 - 52
+                | otherwise -> loop
+       in loop
 
 fromByteVector :: V.Vector Word8 -> ByteString
 fromByteVector v =
@@ -176,13 +183,13 @@ fromByteVector v =
 
 mkFileInfoLBS :: Text -> Text -> L.ByteString -> FileInfo
 mkFileInfoLBS name ct lbs =
-    FileInfo name ct (sourceList $ L.toChunks lbs) (`L.writeFile` lbs)
+    FileInfo name ct (sourceLazy lbs) (`L.writeFile` lbs)
 
 mkFileInfoFile :: Text -> Text -> FilePath -> FileInfo
-mkFileInfoFile name ct fp = FileInfo name ct (sourceFile fp) (\dst -> runResourceT $ sourceFile fp $$ sinkFile dst)
+mkFileInfoFile name ct fp = FileInfo name ct (sourceFile fp) (\dst -> runConduitRes $ sourceFile fp .| sinkFile dst)
 
-mkFileInfoSource :: Text -> Text -> Source (ResourceT IO) ByteString -> FileInfo
-mkFileInfoSource name ct src = FileInfo name ct src (\dst -> runResourceT $ src $$ sinkFile dst)
+mkFileInfoSource :: Text -> Text -> ConduitT () ByteString (ResourceT IO) () -> FileInfo
+mkFileInfoSource name ct src = FileInfo name ct src (\dst -> runConduitRes $ src .| sinkFile dst)
 
 tokenKey :: IsString a => a
 tokenKey = "_TOKEN"
