@@ -11,11 +11,6 @@
 module Yesod.Core.Types where
 
 import qualified Data.ByteString.Builder            as BB
-#if __GLASGOW_HASKELL__ < 710
-import           Control.Applicative                (Applicative (..))
-import           Control.Applicative                ((<$>))
-import           Data.Monoid                        (Monoid (..))
-#endif
 import           Control.Arrow                      (first)
 import           Control.Exception                  (Exception)
 import           Control.Monad                      (ap)
@@ -57,7 +52,6 @@ import           Yesod.Core.Internal.Util           (getTime, putTime)
 import           Yesod.Routes.Class                 (RenderRoute (..), ParseRoute (..))
 import           Control.Monad.Reader               (MonadReader (..))
 import Control.DeepSeq (NFData (rnf))
-import Control.DeepSeq.Generics (genericRnf)
 import Yesod.Core.TypeCache (TypeMap, KeyedTypeMap)
 import Control.Monad.Logger (MonadLoggerIO (..))
 import UnliftIO (MonadUnliftIO (..), UnliftIO (..))
@@ -323,8 +317,7 @@ data ErrorResponse =
     | PermissionDenied !Text
     | BadMethod !H.Method
     deriving (Show, Eq, Typeable, Generic)
-instance NFData ErrorResponse where
-    rnf = genericRnf
+instance NFData ErrorResponse
 
 ----- header stuff
 -- | Headers to be added to a 'Result'.
